Struct security_framework::authorization::Flags [−][src]
pub struct Flags { /* fields omitted */ }Expand description
The flags used to specify authorization options.
Implementations
An empty flag set that you use as a placeholder when you don’t want any of the other flags.
A flag that permits user interaction as needed.
A flag that permits the Security Server to attempt to grant the rights requested.
A flag that permits the Security Server to grant rights on an individual basis.
A flag that instructs the Security Server to revoke authorization.
A flag that instructs the Security Server to preauthorize the rights requested.
Returns the raw value of the flags currently stored.
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Returns true if there are flags common to both self and other.
Returns true all of the flags in other are contained within self.