Enum security_framework::item::Reference
source · pub enum Reference {
Identity(SecIdentity),
Certificate(SecCertificate),
Key(SecKey),
// some variants omitted
}Expand description
An enum including all objects whose references can be returned from a search.
Note that generic Keychain Items, such as passwords and preferences, do
not have specific object types; they are modeled using dictionaries and so
are available directly as search results in variant SearchResult::Dict.
Variants
Identity(SecIdentity)
A SecIdentity.
Certificate(SecCertificate)
A SecCertificate.
Key(SecKey)
A SecKey.