pub struct SecKey(/* private fields */);Expand description
A type representing an encryption key.
Implementations
Sourceimpl SecKey
impl SecKey
Sourcepub fn new(options: &GenerateKeyOptions) -> Result<Self, CFError>
pub fn new(options: &GenerateKeyOptions) -> Result<Self, CFError>
Translates to SecKeyCreateRandomKey
Sourcepub fn generate(attributes: CFDictionary) -> Result<Self, CFError>
👎Deprecated: Use SecKey::new
pub fn generate(attributes: CFDictionary) -> Result<Self, CFError>
Use SecKey::new
Translates to SecKeyCreateRandomKey
GenerateKeyOptions provides a helper to create an attribute CFDictionary.
Sourcepub fn application_label(&self) -> Option<Vec<u8>>
pub fn application_label(&self) -> Option<Vec<u8>>
Returns the programmatic identifier for the key. For keys of class kSecAttrKeyClassPublic and kSecAttrKeyClassPrivate, the value is the hash of the public key.
Sourcepub fn attributes(&self) -> CFDictionary
pub fn attributes(&self) -> CFDictionary
Translates to SecKeyCopyAttributes
Sourcepub fn external_representation(&self) -> Option<CFData>
pub fn external_representation(&self) -> Option<CFData>
Translates to SecKeyCopyExternalRepresentation
Sourcepub fn public_key(&self) -> Option<Self>
pub fn public_key(&self) -> Option<Self>
Translates to SecKeyCopyPublicKey
Sourcepub fn encrypt_data(
&self,
algorithm: Algorithm,
input: &[u8],
) -> Result<Vec<u8>, CFError>
pub fn encrypt_data( &self, algorithm: Algorithm, input: &[u8], ) -> Result<Vec<u8>, CFError>
Encrypts a block of data using a public key and specified algorithm
Sourcepub fn decrypt_data(
&self,
algorithm: Algorithm,
input: &[u8],
) -> Result<Vec<u8>, CFError>
pub fn decrypt_data( &self, algorithm: Algorithm, input: &[u8], ) -> Result<Vec<u8>, CFError>
Decrypts a block of data using a private key and specified algorithm
Sourcepub fn create_signature(
&self,
algorithm: Algorithm,
input: &[u8],
) -> Result<Vec<u8>, CFError>
pub fn create_signature( &self, algorithm: Algorithm, input: &[u8], ) -> Result<Vec<u8>, CFError>
Creates the cryptographic signature for a block of data using a private key and specified algorithm.
Sourcepub fn verify_signature(
&self,
algorithm: Algorithm,
signed_data: &[u8],
signature: &[u8],
) -> Result<bool, CFError>
pub fn verify_signature( &self, algorithm: Algorithm, signed_data: &[u8], signature: &[u8], ) -> Result<bool, CFError>
Verifies the cryptographic signature for a block of data using a public key and specified algorithm.