Module security_framework::os::macos::code_signing [−][src]
Code signing services.
Structs
| Flags | Values that can be used in the flags parameter to most code signing functions. |
| GuestAttributes | A helper to create guest attributes, which are normally passed as a
|
| SecCode | A code object representing signed code running on the system. |
| SecRequirement | A code object representing signed code running on the system. |
| SecStaticCode | A static code object representing signed code on disk. |