pub struct SessionState(_);
Specifies the state of a TLS session.
The session has not yet started.
The session is in the handshake process.
The session is connected.
The session has been terminated.
The session has been aborted due to an error.
Formats the value using the given formatter.
Read more
This method tests for
self and
other values to be equal, and is used
by
==.
Read more
This method tests for
!=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.