SslProtocol

Struct SslProtocol 

pub struct SslProtocol(/* private fields */);
Specifies protocol versions.

Implementations

Source

impl SslProtocol

pub const ALL: Self

All supported TLS/SSL versions are accepted.

pub const DTLS1: Self

The DTLSv1 protocol is preferred.

pub const SSL2: Self

Only the SSL 2.0 protocol is accepted.

pub const SSL3: Self

The SSL 3.0 protocol is preferred, though SSL 2.0 may be used if the peer does not support SSL 3.0.

pub const SSL3_ONLY: Self

Only the SSL 3.0 protocol is accepted.

pub const TLS1: Self

The TLS 1.0 protocol is preferred, though lower versions may be used if the peer does not support TLS 1.0.

pub const TLS11: Self

The TLS 1.1 protocol is preferred, though lower versions may be used if the peer does not support TLS 1.1.

pub const TLS12: Self

The TLS 1.2 protocol is preferred, though lower versions may be used if the peer does not support TLS 1.2.

pub const TLS13: Self

The TLS 1.3 protocol is preferred, though lower versions may be used if the peer does not support TLS 1.3.

pub const TLS1_ONLY: Self

Only the TLS 1.0 protocol is accepted.

pub const UNKNOWN: Self

No protocol has been or should be negotiated or specified; use the default.