pub trait SecCertificateExt {
// Required methods
fn common_name(&self) -> Result<String, Error>;
fn public_key(&self) -> Result<SecKey, Error>;
fn properties(
&self,
keys: Option<&[CertificateOid]>,
) -> Result<CertificateProperties, CFError>;
// Provided method
fn fingerprint(&self) -> Result<[u8; 32], CFError> { ... }
}Expand description
An extension trait adding OSX specific functionality to SecCertificate.
Required Methods
Sourcefn common_name(&self) -> Result<String, Error>
fn common_name(&self) -> Result<String, Error>
Returns the common name associated with the certificate.
Sourcefn public_key(&self) -> Result<SecKey, Error>
fn public_key(&self) -> Result<SecKey, Error>
Returns the public key associated with the certificate.
Sourcefn properties(
&self,
keys: Option<&[CertificateOid]>,
) -> Result<CertificateProperties, CFError>
fn properties( &self, keys: Option<&[CertificateOid]>, ) -> Result<CertificateProperties, CFError>
Returns the set of properties associated with the certificate.
The keys argument can optionally be used to filter the properties loaded to an explicit
subset.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".